@@ -478,9 +478,22 @@ class ScreenerData:
     def url(self, url):
         if url is not None:
             self._url = url
-        
+            
     def get(self):
-        page = requests.get(self.url)
+        data = pd.DataFrame()
+        for i in range(10):
+            url = self.url + '?page=' + str(i+1)
+            df = self._getData(url)
+            if int(df['S.No.'].values[0]) != 25*(i) + 1:
+                break
+            else:
+                data = pd.concat([data, df])
+        data.dropna(inplace = True)
+        data.reset_index(inplace=True, drop = True)
+        return data
+        
+    def _getData(self, url):
+        page = requests.get(url)
         soup = BeautifulSoup(page.content, "html.parser")
         result = [x.find("tbody") for x in soup.find_all("table")]
         
@@ -497,14 +510,18 @@ class ScreenerData:
             i = 0
             temp = {}
             for detail in details:
-                if detail.find('a') is not None:
-                    value = next(detail.find('a').children).strip()
-                else:
-                    value = next(detail.children).strip()
                 try:
-                    value = float(value)
+                    if detail.find('a') is not None:
+                        temp['Symbol'] = detail.find('a').attrs['href'].split('/')[2]
+                        value = next(detail.find('a').children).strip()
+                    else:
+                        value = next(detail.children).strip()
+                    try:
+                        value = float(value)
+                    except:
+                        pass
                 except:
-                    pass
+                    value = ''
                 temp[headers[i]] = value
                 i += 1
             data.append(temp)
@@ -574,4 +591,25 @@ class GrowthPortfolio:
                 message += 'LTP: ' + str(round(stock['CMP'], 2)) + '\n'
                 message += 'Quantity: ' + str(round(stock['Quantity'], 2)) + '\n\n'
             return message
+        return data
+    
+class GoodLargeCapsCloseTo200DMA:
+    
+    def screener(self, formatMessage = True):
+        url = 'https://www.screener.in/screens/457921/CheapLargeCaps/'
+        obj = ScreenerData(url)
+        data = obj.get()
+        data.reset_index( inplace = True, drop = True)
+
+        # Strategy
+        amount_per_stock = 10000
+        data['Quantity'] = round(amount_per_stock/data['CMP'],0)
+        
+        if formatMessage:
+            message = '<b>Large Caps close to 200DMA</b>\nInvest: 10K per ticker\n\n'
+            for stock in data.to_dict(orient = 'record'):
+                message += '<b>' + stock['Name'] + '</b>\n'
+                message += 'LTP: ' + str(round(stock['CMP'], 2)) + '\n'
+                message += 'Quantity: ' + str(round(stock['Quantity'], 2)) + '\n\n'
+            return message
         return data
\ No newline at end of file
